@@ -33,7 +33,7 @@ uniquegenelist <- function(genelist,ndups=2,spacing=1) {
 duplicateCorrelation <- function(object,design=NULL,ndups=2,spacing=1,block=NULL,trim=0.15,weights=NULL)
 #	Estimate the correlation between duplicates given a series of arrays
 #	Gordon Smyth
-#	25 Apr 2002. Last revised 28 July 2013.
+#	25 Apr 2002. Last revised 14 January 2015.
 {
 #	Extract components from y
 	y <- getEAWP(object)
@@ -97,8 +97,9 @@ duplicateCorrelation <- function(object,design=NULL,ndups=2,spacing=1,block=NULL
 		design <- design %x% rep(1,ndups)
 	}
 
-	require( "statmod" ) # need mixedModel2Fit function
+	if(!requireNamespace("statmod",quietly=TRUE)) stop("statmod package required but is not installed")
 	rho <- rep(NA,ngenes)
+	nafun <- function(e) NA
 	for (i in 1:ngenes) {
 		y <- drop(M[i,])
 		o <- is.finite(y)
@@ -111,10 +112,10 @@ duplicateCorrelation <- function(object,design=NULL,ndups=2,spacing=1,block=NULL
 			Z <- model.matrix(~0+A)
 			if(!is.null(weights)) {
 				w <- drop(weights[i,])[o]
-				s <- mixedModel2Fit(y,X,Z,w,only.varcomp=TRUE,maxit=20)$varcomp
+				s <- tryCatch(statmod::mixedModel2Fit(y,X,Z,w,only.varcomp=TRUE,maxit=20)$varcomp,error=nafun)
 			} else
-				s <- mixedModel2Fit(y,X,Z,only.varcomp=TRUE,maxit=20)$varcomp
-			rho[i] <- s[2]/sum(s)
+				s <- tryCatch(statmod::mixedModel2Fit(y,X,Z,only.varcomp=TRUE,maxit=20)$varcomp,error=nafun)
+			if(!is.na(s[1])) rho[i] <- s[2]/sum(s)
 		}
 	}
 	arho <- atanh(pmax(-1,rho))
@@ -192,14 +193,15 @@ avedups.EList <- function(x,ndups=x$printer$ndups,spacing=x$printer$spacing,weig
 	y
 }
 
-avereps <- function(x,ID) UseMethod("avereps")
-#  4 June 2008
+avereps <- function(x,...)
+#	4 June 2008
+	UseMethod("avereps")
 
-avereps.default <- function(x,ID=rownames(x))
+avereps.default <- function(x,ID=rownames(x),...)
 #	Average over irregular replicate spots, for matrices or vectors
 #	Gordon Smyth
 #	Created 3 June 2008.  Last modified 1 Dec 2010.
-#  Revised 19 Aug 2009 following suggestions from Axel Klenk.
+#	Revised 19 Aug 2009 following suggestions from Axel Klenk.
 #	Revised 28 March 2010 following suggestion from Michael Lawrence.
 {
 	if(is.null(x)) return(NULL)
@@ -219,7 +221,7 @@ avereps.default <- function(x,ID=rownames(x))
 	y/n
 }
 
-avereps.MAList <- function(x,ID=NULL)
+avereps.MAList <- function(x,ID=NULL,...)
 #	Average over irregular replicate spots for MAList objects
 #	Gordon Smyth
 #	3 June 2008.  Last modified 8 Sep 2010.
@@ -236,11 +238,11 @@ avereps.MAList <- function(x,ID=NULL)
 	for (a in other) y$other[[a]] <- avereps(x$other[[a]],ID=ID)
 	y$weights <- avereps(x$weights,ID=ID)
 	y$genes <- x$genes[!duplicated(ID),]
-   y$printer <- NULL
+	y$printer <- NULL
 	y
 }
 
-avereps.EList <- function(x,ID=NULL)
+avereps.EList <- function(x,ID=NULL,...)
 #	Average over irregular replicate probes for EList objects
 #	Gordon Smyth
 #	2 April 2010.  Last modified 20 May 2011.
@@ -256,6 +258,25 @@ avereps.EList <- function(x,ID=NULL)
 	for (a in other) y$other[[a]] <- avereps(x$other[[a]],ID=ID)
 	y$weights <- avereps(x$weights,ID=ID)
 	y$genes <- x$genes[!duplicated(ID),]
-   y$printer <- NULL
+	y$printer <- NULL
 	y
 }
+
+avereps.RGList <- function(x,ID=NULL,...)
+#	Warn users that averaging should not be applied prior to normalization
+#	Gordon Smyth
+#	2 December 2013.
+{
+	stop("avereps should not be applied to an RGList object")
+	invisible()
+}
+
+
+avereps.EListRaw <- function(x,ID=NULL,...)
+#	Warn users that averaging should not be applied prior to normalization
+#	Gordon Smyth
+#	2 December 2013.
+{
+	stop("avereps should not be applied to an EListRaw object")
+	invisible()
+}
