@@ -45,14 +45,22 @@ f1 <- quantile(out$fitted)
 r1 <- quantile(out$residual)
 w <- rep(1,100)
 w[1:50] <- 0.5
-out <- loessFit(y,x,weights=w)
+out <- loessFit(y,x,weights=w,method="weightedLowess")
 f2 <- quantile(out$fitted)
 r2 <- quantile(out$residual)
-w[1:80] <- 0
-out <- loessFit(y,x,weights=w)
+out <- loessFit(y,x,weights=w,method="locfit")
 f3 <- quantile(out$fitted)
 r3 <- quantile(out$residual)
-data.frame(f1,f2,f3,r1,r2,r3)
+out <- loessFit(y,x,weights=w,method="loess")
+f4 <- quantile(out$fitted)
+r4 <- quantile(out$residual)
+w <- rep(1,100)
+w[2*(1:50)] <- 0
+out <- loessFit(y,x,weights=w,method="weightedLowess")
+f5 <- quantile(out$fitted)
+r5 <- quantile(out$residual)
+data.frame(f1,f2,f3,f4,f5)
+data.frame(r1,r2,r3,r4,r5)
 
 ### normalizeWithinArrays
 
@@ -117,6 +125,7 @@ toptable(fit)
 
 ### topTable
 
+rownames(M) <- LETTERS[1:10]
 fit <- lmFit(M,design)
 fit2 <- eBayes(contrasts.fit(fit,contrasts=contrast.matrix))
 topTable(fit2)
@@ -216,11 +225,18 @@ y[iset1,3:4] <- y[iset1,3:4]+3
 iset2 <- 6:10
 roast(y=y,iset1,design,contrast=2)
 roast(y=y,iset1,design,contrast=2,array.weights=c(0.5,1,0.5,1))
-mroast(y=y,list(set1=iset1,set2=iset2),design,contrast=2)
+w <- matrix(runif(100*4),100,4)
+roast(y=y,iset1,design,contrast=2,weights=w)
 mroast(y=y,list(set1=iset1,set2=iset2),design,contrast=2,gene.weights=runif(100))
+mroast(y=y,list(set1=iset1,set2=iset2),design,contrast=2,array.weights=c(0.5,1,0.5,1))
+mroast(y=y,list(set1=iset1,set2=iset2),design,contrast=2,weights=w)
+mroast(y=y,list(set1=iset1,set2=iset2),design,contrast=2,weights=w,array.weights=c(0.5,1,0.5,1))
+fry(y=y,list(set1=iset1,set2=iset2),design,contrast=2,weights=w,array.weights=c(0.5,1,0.5,1))
 
 ### camera
 
+camera(y=y,iset1,design,contrast=2,weights=c(0.5,1,0.5,1),allow.neg.cor=TRUE,inter.gene.cor=NA)
+camera(y=y,list(set1=iset1,set2=iset2),design,contrast=2,allow.neg.cor=TRUE,inter.gene.cor=NA)
 camera(y=y,iset1,design,contrast=2,weights=c(0.5,1,0.5,1))
 camera(y=y,list(set1=iset1,set2=iset2),design,contrast=2)
 
@@ -228,6 +244,7 @@ camera(y=y,list(set1=iset1,set2=iset2),design,contrast=2)
 
 y <- new("EList",list(E=y))
 roast(y=y,iset1,design,contrast=2)
+camera(y=y,iset1,design,contrast=2,allow.neg.cor=TRUE,inter.gene.cor=NA)
 camera(y=y,iset1,design,contrast=2)
 
 ### eBayes with trend
@@ -248,3 +265,28 @@ fit$df.residual[1]
 fit$df.prior
 fit$s2.prior
 summary(fit$s2.post)
+
+### voom
+
+y <- matrix(rpois(100*4,lambda=20),100,4)
+design <- cbind(Int=1,x=c(0,0,1,1))
+v <- voom(y,design)
+names(v)
+summary(v$E)
+summary(v$weights)
+
+### goana
+
+EB <- c("133746","1339","134","1340","134083","134111","134147","134187","134218","134266",
+"134353","134359","134391","134429","134430","1345","134510","134526","134549","1346",
+"134637","1347","134701","134728","1348","134829","134860","134864","1349","134957",
+"135","1350","1351","135112","135114","135138","135152","135154","1352","135228",
+"135250","135293","135295","1353","135458","1355","1356","135644","135656","1357",
+"1358","135892","1359","135924","135935","135941","135946","135948","136","1360",
+"136051","1361","1362","136227","136242","136259","1363","136306","136319","136332",
+"136371","1364","1365","136541","1366","136647","1368","136853","1369","136991",
+"1370","137075","1371","137209","1373","137362","1374","137492","1375","1376",
+"137682","137695","137735","1378","137814","137868","137872","137886","137902","137964")
+go <- goana(fit,FDR=0.8,geneid=EB)
+topGO(go,n=10,truncate.term=30)
+topGO(go,n=10,truncate.term=30,sort="down")
